/*	
 *	Modellazione e Resa realistica con XCModel Assegnato il 26/05/2008 
 * 	di Marcello Borsari - marcello.borsari@gmail.com
 *
 * 	soggetto: Mike Wazowski di Monster & Co.
 *
 *	Scena
*/	


#include "descriptor/descriptor.h"
#include <stdio.h>

int main(void) {
	
	// Oggetti -------------------------------------------------------------------------------

	ITEM scene;
	ITEM Light1,Light2;

	// Mike
	ITEM mike;
	ITEM armR_1, armR_2, handR; 	
	ITEM armL_1, armL_2, handL;	
	ITEM body, eye, eyebrownup, eyebrowndown, mouth, tooth1, tooth2, tooth3, tooth4, hornL, hornR;
	ITEM footR, footL, toenail1, toenail2, toenail3, toenail4, toenail5, toenail6;

	// Stanza e oggetti
	ITEM room, lamp, chair, chair_wood, chair_pillow;
	ITEM lcd, lcd_1, lcd_2, lcd_3, lcd_4, lcd_5;
	ITEM ceiling, floor, wback, wfront, wleft, wright;
	ITEM table, table_up, table_down, table_l1, table_l2, table_l3, table_l4;
	ITEM dvd, dvdobj, dvdcover1, dvdcover2;

	ITEM poster, poster_ext, poster_int, shelf;


	// Materiali ------------------------------------------------------------------------------
	
	ITEM wood, plaster, skin, ivory, eye_attr, chrome, plastic, metal;

	wood = create_attribute("wood");
	set_color(wood,0.4,0.3,0.1,0.2,0.3);
	set_reflectivity(wood,0.05,1.5);

	plaster = create_attribute("plaster");
	set_color(plaster,0.83,0.82,0.8,0.1,0.7);
	set_reflectivity(plaster,0,12);

	skin = create_attribute("skin");
	set_color(skin,0.59,0.82,0.2,0.1,0.7);
	set_reflectivity(skin,0,0);

	ivory = create_attribute("ivory");
	set_color(ivory,0.99,0.96,0.89,0.2,0.8);
	set_reflectivity(ivory,0,0);

	eye_attr = create_attribute("eye_attr");
	set_color(eye_attr,0.5,0.5,0.5,0.9,0.8);
	set_reflectivity(eye_attr,0,1);
	set_transparency(eye_attr, 0.3, 0.2, 0.0, 8);

	chrome = create_attribute("chrome");
	set_color(chrome,0.15,0.15,0.15,0.15,0.15);
	set_reflectivity(chrome,0.8,20);
	
	metal = create_attribute("metal");
	set_color(metal,0.72,0.72,0.72,0.1,0.449);
	set_reflectivity(metal,0.2,128);

	plastic = create_attribute("plastic");
	set_color(plastic,0.1,0.1,0.1,0.1,0.7);
	set_reflectivity(plastic,0,12);


	// Luci  ----------------------------------------------------------------------------------

	set_background(0.675,0.855,0.953,TRUE);
	set_ambient_light(0.9,0.9,0.9,2.5);
		
	// Luce lampada di sinistra (Temp. Colore verso il rosso)
	Light1 = create_point_light(-7.2, -3.8, 10.0,  1,0.89,0.78,2.7,22, "Light1");

	Light2 = create_warn_light(-7.24,-7.38,5.84,0.61,0.31,-0.73,1,1,1,2.8,11,0,33.0,0,0.0,0.0,0.0,0.0, "Light2");


	// Generazione modelli ---------------------------------------------------------------------

	
	// Lettura NURBS Mike
	armL_1 = read_nurbs("Mike_ArmL_1.db");		armL_2 = read_nurbs("Mike_ArmL_2.db");
	armR_1 = read_nurbs("Mike_ArmR_1.db"); 		armR_2 = read_nurbs("Mike_ArmR_2.db");

	handR = read_obj("Mike_HandR.obj", "handR");
	handL = read_obj("Mike_HandL.obj", "handL");

	body = read_nurbs("Mike_Body.dbe");		eye = read_nurbs("Mike_Eye.db");	
	eyebrowndown = read_nurbs("Mike_EyeBrowDown.db");	eyebrownup = read_nurbs("Mike_EyeBrowUp.db");
	tooth1 = read_nurbs("Mike_Tooth_1.db");		tooth2 = read_nurbs("Mike_Tooth_2.db");
	tooth3 = read_nurbs("Mike_Tooth_3.db");		tooth4 = read_nurbs("Mike_Tooth_4.db");
	hornL = read_nurbs("Mike_HornL.db");		hornR = read_nurbs("Mike_HornR.db");
	mouth = read_nurbs("Mike_Mouth.db");
	
	footR = read_nurbs("Mike_FootR.db");		footL = read_nurbs("Mike_FootL.db");
	toenail1 = read_nurbs("Mike_ToeNail_1.db");	toenail2 = read_nurbs("Mike_ToeNail_2.db");
	toenail3 = read_nurbs("Mike_ToeNail_3.db");	toenail4 = read_nurbs("Mike_ToeNail_4.db");
	toenail5 = read_nurbs("Mike_ToeNail_5.db");	toenail6 = read_nurbs("Mike_ToeNail_6.db");


	// Modello Mike

	mike = create_list(body, "mike");		mike = insert_in_list(mike, armL_1);
	mike = insert_in_list(mike, armL_2);		mike = insert_in_list(mike, armR_1);
	mike = insert_in_list(mike, armR_2);		mike = insert_in_list(mike, handR);
	mike = insert_in_list(mike, handL);		mike = insert_in_list(mike, eye);
	mike = insert_in_list(mike, eyebrowndown);	mike = insert_in_list(mike, mouth);
	mike = insert_in_list(mike, eyebrownup);	
	mike = insert_in_list(mike, tooth1);		mike = insert_in_list(mike, tooth2);
	mike = insert_in_list(mike, tooth3);		mike = insert_in_list(mike, tooth4);
	mike = insert_in_list(mike, hornL);		mike = insert_in_list(mike, hornR);
	mike = insert_in_list(mike, footR);		mike = insert_in_list(mike, footL);
	mike = insert_in_list(mike, toenail1);		mike = insert_in_list(mike, toenail2);
	mike = insert_in_list(mike, toenail3);		mike = insert_in_list(mike, toenail4);
	mike = insert_in_list(mike, toenail5);		mike = insert_in_list(mike, toenail6);


	// Lettura NURBS LCD
	
	lcd_1 = read_nurbs("LCD_1.db");			lcd_2 = read_nurbs("LCD_2.db");
	lcd_3 = read_nurbs("LCD_3.db");			lcd_4 = read_nurbs("LCD_4.db");
	lcd_5 = read_nurbs("LCD_5.db");

	lcd = create_list(lcd_1, "lcd");		lcd = insert_in_list(lcd, lcd_2);
	lcd = insert_in_list(lcd, lcd_3);		lcd = insert_in_list(lcd, lcd_4);
	lcd = insert_in_list(lcd, lcd_5);


	// Lettura NURBS Parete
		
	ceiling = read_nurbs("room_ceiling.db");	floor = read_nurbs("room_floor.db");
	wback = read_nurbs("room_wback.db");		wfront = read_nurbs("room_wfront.db");
	wleft = read_nurbs("room_wleft.db");		wright = read_nurbs("room_wright.db");

	room = create_list(ceiling, "room");		room = insert_in_list(room, floor);
	room = insert_in_list(room, wback);		room = insert_in_list(room, wfront);
	room = insert_in_list(room, wleft);		room = insert_in_list(room, wright);


	// Lettura NURBS Tavolo

	table_up = read_nurbs("tavolosup.db"); 		table_down = read_nurbs("tavoloinf.db");
	table_l1 = read_nurbs("gamba.db");		table_l2 = read_nurbs("gamba2.db");
	table_l3 = read_nurbs("gamba3.db");		table_l4 = read_nurbs("gamba4.db");

	table = create_list(table_up, "table");		table = insert_in_list(table, table_down);
	table = insert_in_list(table, table_l1);	table = insert_in_list(table, table_l2);
	table = insert_in_list(table, table_l3);	table = insert_in_list(table, table_l4);


	// Lettura NURBS Poster

	poster_ext = read_nurbs("quadro.db"); 		poster_int = read_nurbs("superficie_quadro.db");
	poster = create_list(poster_ext, "poster");	poster = insert_in_list(poster, poster_int);

	
	// Lettura NURBS Lampada
	lamp = read_obj("lampada.obj", "lamp");		
	set_attribute(lamp,metal);


	// Lettura NURBS Sedia
	chair_wood = read_obj("Chair.obj", "chair_wood");
	set_attribute(chair_wood,wood);

	chair_pillow = read_nurbs("piano.db");
	
	chair = create_list(chair_wood, "chair");	chair = insert_in_list(chair, chair_pillow);


	// Lettura NURBS DVD
	dvdobj = read_obj("Bookclose.obj", "dvdobj");
	set_attribute(dvdobj,plastic);

	dvdcover1 = read_nurbs("copertina3.db");
	
	dvd = create_list(dvdobj, "dvd");		dvd = insert_in_list(dvd, dvdcover1);
	

	// Attributi e texture

	set_attribute(lcd, plastic);
	set_attribute(lcd_5, metal);

	set_attribute(ceiling, plaster);
	set_attribute(floor, plaster);
	set_attribute(wback, plaster);
	set_attribute(wfront, plaster);
	set_attribute(wleft, plaster);
	set_attribute(wright, plaster);

	set_domain_texture(wback, plaster, "textures/plaster.hr",0,0.1,0,0.1,1,0.2,0.5);
	set_domain_texture(wfront, plaster, "textures/plaster.hr",0,0.1,0,0.1,1,0.2,0.5);
	set_domain_texture(wleft, plaster, "textures/plaster.hr",0,0.1,0,0.1,1,0.2,0.5);	// *
	set_domain_texture(wright, plaster, "textures/plaster.hr",0,0.1,0,0.1,1,0.2,0.5);
	set_domain_texture(floor, plaster, "textures/floor.hr",0,1,0,1,1,0.2,0.5);
	set_domain_texture(ceiling, plaster, "textures/plaster.hr",0,0.1,0,0.1,1,0.2,0.5);
	

	set_attribute(mike, skin);			set_attribute(tooth1, ivory);
	set_attribute(tooth2, ivory);			set_attribute(tooth3, ivory);
	set_attribute(tooth4, ivory);			set_attribute(eye, eye_attr);
	set_attribute(hornL, ivory);			set_attribute(hornR, ivory);
	set_attribute(toenail1, ivory);			set_attribute(toenail2, ivory);
	set_attribute(toenail3, ivory);			set_attribute(toenail4, ivory);
	set_attribute(toenail5, ivory);			set_attribute(toenail6, ivory);

	set_domain_texture(mike, skin, "textures/skin.hr",0,0.5,0,0.5,1,0.4,0.5);
	set_domain_texture(eye, ivory, "textures/eye.hr",0,0.7,0,0.5,1,0.5,0.5);
	set_domain_texture(hornR, ivory, "textures/horn.hr",0,1,0,0.5,1,0.3,0.4);
	set_domain_texture(hornL, ivory, "textures/horn.hr",0,1,0,0.5,1,0.3,0.4);
	set_domain_texture(hornL, ivory, "textures/horn.hr",0,1,0,0.5,1,0.3,0.4);
	set_domain_texture(tooth1, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);
	set_domain_texture(tooth2, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);
	set_domain_texture(tooth3, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);
	set_domain_texture(tooth4, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);
	set_domain_texture(toenail1, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);
	set_domain_texture(toenail2, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);
	set_domain_texture(toenail3, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);
	set_domain_texture(toenail4, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);
	set_domain_texture(toenail5, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);
	set_domain_texture(toenail6, ivory, "textures/ivory.hr",0,0.5,0,0.5,1,0.3,0.4);

	set_attribute(table_up, wood);			set_attribute(table_down, wood);
	set_attribute(table_l1, chrome);		set_attribute(table_l2, chrome);
	set_attribute(table_l3, chrome);		set_attribute(table_l4, chrome);

	set_domain_texture(table_up, wood, "textures/wood.hr",0,0.1,0,0.1,1,0.3,0.4);
	set_domain_texture(table_down, wood, "textures/wood.hr",0,0.1,0,0.6,1,0.3,0.4);

	set_domain_texture(poster_int, plaster, "textures/poster.hr",0,1,0,1,0,0.3,0.4);
	set_domain_texture(lcd_1, plaster, "textures/lcd.hr",0,1,0,1,0,0.5,0.6);

	set_domain_texture(chair_wood, wood, "textures/wood.hr",0,0.1,0,0.6,1,0.3,0.4);
	set_domain_texture(chair_pillow, wood, "textures/pillow.hr",0,0.1,0,0.6,1,0.3,0.4);

	set_domain_texture(dvdcover1, plastic, "textures/dvdcover.hr",0.25,0.9,0.01,0.99,0,0.3,0.4);
		
		
	// Generazione Scena

	set_scale(table,0.1,0.1,0.1);	
	set_translate(table,-10,-10,-2.4);
	
	set_scale(mike,0.3,0.3,0.3);	
	set_z_rotate(mike,35,1);	
	set_translate(mike,-3,-6,2.5);	

	set_scale(lcd,0.3,0.3,0.3);
	set_translate(lcd,-6,-7,2.6);
	set_z_rotate(lcd,20,1);

	set_scale(poster,1,1.2,1.6);
	set_x_rotate(poster,90,1);
	set_translate(poster,-5,1,8);	
	set_z_rotate(poster,90,1);

	set_z_rotate(lamp,-60,1);
	set_scale(lamp,2.0,2.0,2.0);
	set_translate(lamp,-5,-6,2.3);

	set_z_rotate(chair,150,1);
	set_scale(chair,0.07,0.07,0.07);	
	set_translate(chair,0,-2,-3);

	set_z_rotate(dvd,-55,1);
	set_scale(dvd,0.18,0.2,0.05);
	set_translate(dvd,-6,-6,2.5);
	
	scene = create_list(room, "scene");
	scene = insert_in_list(scene, table);
	scene = insert_in_list(scene, mike);
	scene = insert_in_list(scene, lcd);
	scene = insert_in_list(scene, lamp);
	scene = insert_in_list(scene, chair);
	scene = insert_in_list(scene, dvd);
	scene = insert_in_list(scene, poster);

	save_scene("mike.md","Mike",scene);

	return(0);
}

